@@ -185,7 +185,7 @@ request_async_data_new (WebKitURISchemeRequest *request, gchar *page_id)
 {
     RequestAsyncData *data;
 
-    data = g_slice_new (RequestAsyncData);
+    data = g_slice_new0 (RequestAsyncData);
     data->request = g_object_ref (request);
     data->page_id = g_strdup (page_id);
     return data;
@@ -787,7 +787,6 @@ document_callback (YelpDocument       *document,
                                       stream,
                                       content_length,
                                       mime_type);
-    request_async_data_free (data);
     g_free (mime_type);
     g_object_unref (stream);
 }
@@ -810,7 +809,8 @@ help_cb_uri_resolved (YelpUri                *uri,
                                     data->page_id,
                                     NULL,
                                     (YelpDocumentCallback) document_callback,
-                                    data);
+                                    data,
+                                    (GDestroyNotify) request_async_data_free);
         g_object_unref (document);
 
     } else {
@@ -1758,8 +1758,7 @@ view_print_action (GAction *action, GVariant *parameter, YelpView *view)
     gtk_print_settings_set (settings,
                             GTK_PRINT_SETTINGS_OUTPUT_BASENAME,
                             priv->page_title);
-    gtk_print_operation_set_print_settings (GTK_PRINT_OPERATION (print_operation),
-                                            settings);
+    webkit_print_operation_set_print_settings (print_operation, settings);
 
     webkit_print_operation_run_dialog (print_operation, GTK_WINDOW (window));
     g_object_unref (print_operation);
